==> paraview-v2.6.2.zip: paraview-v2.6.2/Servers/Common/vtkPVOpenGLExtensionsInformation.h <==
/*=========================================================================

  Program:   ParaView
  Module:    vtkPVOpenGLExtensionsInformation.h

  Copyright (c) Kitware, Inc.
  All rights reserved.
  See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkPVOpenGLExtensionsInformation - Information object
// to obtain information about OpenGL extensions.
// .SECTION Description
// Information object that can be used to obtain OpenGL extension
// information. The object from which the information is obtained
// should be the process module.
// One can directly instantiate this class and gather information,
// however, to avoid repeated extension queries, vtkProcessModule
// also provides API to access the vtkPVOpenGLExtensionsInformation object
// for every connection.
#ifndef __vtkPVOpenGLExtensionsInformation_h
#define __vtkPVOpenGLExtensionsInformation_h

#include "vtkPVInformation.h"

class vtkPVOpenGLExtensionsInformationInternal;

class VTK_EXPORT vtkPVOpenGLExtensionsInformation : public vtkPVInformation
{
public:
  static vtkPVOpenGLExtensionsInformation* New();
  vtkTypeRevisionMacro(vtkPVOpenGLExtensionsInformation, vtkPVInformation);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Transfer information about a single object into this object.
  virtual void CopyFromObject(vtkObject*);

  bool ExtensionSupported(const char* ext);

  // Description:
  // Manage a serialized version of the information.
  virtual void CopyToStream(vtkClientServerStream*);
  virtual void CopyFromStream(const vtkClientServerStream*);

  // Description:
  // Merge another information object.
  virtual void AddInformation(vtkPVInformation*);
protected:
  vtkPVOpenGLExtensionsInformation();
  ~vtkPVOpenGLExtensionsInformation();

private:
  vtkPVOpenGLExtensionsInformation(const vtkPVOpenGLExtensionsInformation&); // Not implemented.
  void operator=(const vtkPVOpenGLExtensionsInformation&); // Not implemented.

  vtkPVOpenGLExtensionsInformationInternal* Internal;

};

#endif

==> paraview-v3.2.2.zip: paraview-v3.2.2/Servers/Common/vtkPVOpenGLExtensionsInformation.h <==
/*=========================================================================

  Program:   ParaView
  Module:    vtkPVOpenGLExtensionsInformation.h

  Copyright (c) Kitware, Inc.
  All rights reserved.
  See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkPVOpenGLExtensionsInformation - Information object
// to obtain information about OpenGL extensions.
// .SECTION Description
// Information object that can be used to obtain OpenGL extension
// information. The object from which the information is obtained
// should be a render window.
#ifndef __vtkPVOpenGLExtensionsInformation_h
#define __vtkPVOpenGLExtensionsInformation_h

#include "vtkPVInformation.h"

class vtkPVOpenGLExtensionsInformationInternal;

class VTK_EXPORT vtkPVOpenGLExtensionsInformation : public vtkPVInformation
{
public:
  static vtkPVOpenGLExtensionsInformation* New();
  vtkTypeRevisionMacro(vtkPVOpenGLExtensionsInformation, vtkPVInformation);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Transfer information about a single object into this object.
  virtual void CopyFromObject(vtkObject*);

  // Description:
  // Returns if the given extension is supported.
  bool ExtensionSupported(const char* ext);

  // Description:
  // Manage a serialized version of the information.
  virtual void CopyToStream(vtkClientServerStream*);
  virtual void CopyFromStream(const vtkClientServerStream*);

  // Description:
  // Merge another information object.
  virtual void AddInformation(vtkPVInformation*);
protected:
  vtkPVOpenGLExtensionsInformation();
  ~vtkPVOpenGLExtensionsInformation();

private:
  vtkPVOpenGLExtensionsInformation(const vtkPVOpenGLExtensionsInformation&); // Not implemented.
  void operator=(const vtkPVOpenGLExtensionsInformation&); // Not implemented.

  vtkPVOpenGLExtensionsInformationInternal* Internal;

};

#endif
